@@ -1,7 +1,7 @@
 package HTTP::MobileAttribute;
 use strict;
 use warnings;
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 use HTTP::MobileAttribute::Request;
 use HTTP::MobileAttribute::CarrierDetector;
 use UNIVERSAL::require;
@@ -76,6 +76,9 @@ HTTP::MobileAttribute - Yet Another HTTP::MobileAgent
   $agent->is_supported_flash();
   $agent->is_supported_gif();
 
+  # in apache2
+  my $agent = HTTP::MobileAttribute->new($r->headers_in);
+
 =head1 WARNINGS
 
 WE ARE NOW TESTING THE CONCEPT.
